@@ -12,4 +12,4 @@ This package can be used in two ways:
 - Importing "from rook import Rook" allows to manually configure and start the Rook.
 """
 
-from .interface import start, flush, stop
+from .interface import start, flush, stop, restart
