@@ -1,5 +1,6 @@
 """This module implements the Aug class."""
 import time
+import uuid
 
 from rook.logger import logger
 from rook.user_warnings import UserWarnings
@@ -48,7 +49,7 @@ class Aug(object):
             self._location.add_aug(trigger_services, self._output, self)
         except Exception as exc:
             message = "Exception when adding aug"
-            logger.exception(message)
+            logger.exception(message + " " + self.aug_id + " : " + str(exc))
             self.set_error(Error(exc=exc, message=message))
 
     def execute(self, frame_namespace, extracted):
@@ -86,9 +87,10 @@ class Aug(object):
                         return
 
                     executed = True
+                    msg_id = uuid.uuid4().hex
 
-                    logger.info("Executing aug-\t%s", self.aug_id)
-                    self._action.execute(self.aug_id, namespace, self._output)
+                    logger.info("Executing aug-\t%s (msg ID %s)", self.aug_id, msg_id)
+                    self._action.execute(self.aug_id, msg_id, namespace, self._output)
 
         # Don't stop test exceptions from propagating
         except AssertionError:
