@@ -80,7 +80,7 @@ class LocationFileLine(object):
         if file_contents is None:
             return self.lineno
 
-        if self.line_crc32:
+        if self.line_crc32 is not None:
             return self._find_line_using_crc(aug, filepath, file_contents)
 
         if self.file_hash:
