@@ -7,8 +7,8 @@ import select
 import errno
 import certifi
 import ssl
-import platform
-
+import re
+import os
 import six
 import websocket
 
@@ -68,8 +68,7 @@ class AgentCom(object):
     def __init__(self, agent_id, host, port, proxy, token, labels, tags):
         self.id = agent_id
 
-        self._thread = threading.Thread(name="rookout-" + type(self).__name__, target=self._connect)
-        self._thread.daemon = True
+        self._init_connect_thread()
 
         self._host = host if '://' in host else 'ws://' + host
         self._port = port
@@ -94,6 +93,7 @@ class AgentCom(object):
             self._ready_event.set()
 
         self.once('InitialAugsCommand', set_ready_event)
+        self.poll_available = hasattr(select, "poll")
 
     def start(self):
         self._thread.start()
@@ -104,8 +104,25 @@ class AgentCom(object):
         if self._connection is not None:
             self._connection.close(1000)
 
+    def restart(self):
+        self.stop()
+        self._thread.join()
+
+        self._connection = None
+
+        self._init_connect_thread()
+
+        self._running = True
+        self.start()
+
+    def update_info(self, agent_id, tags, labels):
+        self.id = agent_id
+        self._labels = labels or {}
+        self._tags = tags or []
+
     def add(self, message):
-        self._queue.put(wrap_in_envelope(message))
+        if self._queue.qsize() < AgentComConfiguration.MAX_QUEUED_MESSAGES:
+            self._queue.put(wrap_in_envelope(message))
 
     def on(self, message_name, callback):
         self._register_callback(message_name, MessageCallback(callback, True))
@@ -149,7 +166,6 @@ class AgentCom(object):
                         self._ready_event.set()
 
                         logger.error('Connection failed; %s', self._connection_error.get_message())
-                        return
                     raise
             except Exception as e:
                 retry += 1
@@ -220,17 +236,56 @@ class AgentCom(object):
 
             logger.debug("Reconnecting")
 
+    def wait_for_event_poll(self, stop_socket):
+        poller = select.poll()
+
+        exception_flags = select.POLLHUP | select.POLLERR
+        read_only_flags = select.POLLIN | select.POLLPRI | exception_flags
+
+        # Registering all input close and exception types
+        poller.register(self._connection, read_only_flags)
+        poller.register(stop_socket, read_only_flags)
+
+        events = poller.poll(AgentComConfiguration.PING_TIMEOUT * 1000)
+
+        for fd, flag in events:
+            if fd == stop_socket.fileno():
+                return True  # signaled to stop
+            elif fd == self._connection.fileno() and flag \
+                    and flag & exception_flags:  # Checking these flags explicitly (ignore input data)
+                return True
+
+        if len(events) == 0:
+            logger.debug("Incoming thread - ping timeout")
+            return True  # select timed out - ping timeout
+
+        # Every thing is ok
+        return False
+
+    def wait_for_event_select(self, stop_socket):
+        rlist, _, xlist = select.select([self._connection, stop_socket],
+                                        [],
+                                        [self._connection, stop_socket],
+                                        AgentComConfiguration.PING_TIMEOUT)
+        if stop_socket in rlist or stop_socket in xlist or self._connection in xlist:
+            return True  # signaled to stop
+
+        if len(rlist) == 0 and len(xlist) == 0:
+            logger.debug("Incoming thread - ping timeout")
+            return True  # select timed out - ping timeout
+        return False
+
     def _incoming(self, stop_socket, on_exit):
         try:
             while True:
                 try:
-                    rlist, _, xlist = select.select([self._connection, stop_socket], [], [self._connection, stop_socket], AgentComConfiguration.PING_TIMEOUT)
-                    if stop_socket in rlist or stop_socket in xlist or self._connection in xlist:
-                        break  # signaled to stop
-
-                    if len(rlist) == 0 and len(xlist) == 0:
-                        logger.debug("Incoming thread - ping timeout")
-                        break  # select timed out - ping timeout
+                    # Poll has no file_descriptor limit (on linux) if available - use it
+                    if self.poll_available:
+                        if self.wait_for_event_poll(stop_socket):
+                            break
+                    else:
+                        if self.wait_for_event_select(stop_socket):
+                            break
 
                     # it wasn't stop_socket, so it's self._connection -> we can read. we have to read including
                     # control frames, otherwise select might return and recv() wouldn't actually return anything
@@ -309,9 +364,14 @@ class AgentCom(object):
                               timeout=AgentComConfiguration.TIMEOUT,
                               http_proxy_host=proxy_host, http_proxy_port=proxy_port)
 
+        if os.environ.get('ROOKOUT_NO_HOST_HEADER_PORT') == '1':
+            host = re.sub(':\d+$', '', urlparse(url).netloc)
+        else:
+            host = None
+
         try:
             # connect using system certificates
-            conn = websocket.create_connection(*connect_args, **connect_kwargs)
+            conn = websocket.create_connection(*connect_args, host=host, **connect_kwargs)
         # In some very specific scenario, you cannot
         # reference ssl.CertificateError because it does
         # exist, so instead we get with with getattr
@@ -353,6 +413,10 @@ class AgentCom(object):
 
         return self._send(wrap_in_envelope(m))
 
+    def _init_connect_thread(self):
+        self._thread = threading.Thread(name="rookout-" + type(self).__name__, target=self._connect)
+        self._thread.daemon = True
+
     AcceptedMessageTypes = [
         messages_pb.InitialAugsCommand,
         messages_pb.AddAugCommand,
