@@ -33,6 +33,9 @@ class Output(object):
                                                                                        "Limit reached, dropping log messages"))
         logger.register_output(self)
 
+    def set_agent_id(self, agent_id):
+        self._id = agent_id
+
     def set_agent_com(self, agent_com):
         self._agent_com = agent_com
 
@@ -52,7 +55,7 @@ class Output(object):
             self._agent_com.add(rule_status_message)
         self._rule_status_updates_bucket.do_if_available(send_msg)
 
-    def send_user_message(self, aug_id, arguments):
+    def send_user_message(self, aug_id, message_id, arguments):
         if not self._agent_com:
             return
 
@@ -60,6 +63,7 @@ class Output(object):
             msg = AugReportMessage()
             msg.agent_id = self._id
             msg.aug_id = aug_id
+            msg.report_id = message_id
 
             if arguments and arguments.size(''):
                 NamespaceSerializer().dump(arguments, msg.arguments)
