@@ -13,6 +13,9 @@ _rook = None
 _debug = False
 _throw_errors = False
 
+_fork = None
+_original_args = None
+
 _TRUE_VALUES = ['y', 'Y', 'yes',  'Yes',  'YES', 'true', 'True', 'TRUE', '1', True]
 
 
@@ -30,12 +33,26 @@ def start(token=None,
           git_commit=None,
           git_origin=None,
           proxy=None,
+          fork=None,
           **kwargs):
-    global _rook, _debug, _throw_errors
+    global _rook, _debug, _throw_errors, _original_args, _fork
 
     if _rook is not None:
         return
 
+    if _original_args:
+        copy_of_original_args = _original_args
+        _original_args = None
+
+        # Disable fork support on child processes
+        copy_of_original_args['fork'] = False
+
+        start(**copy_of_original_args)
+        return
+
+    # Save original args to recover from fork
+    _original_args = locals()
+
     if isinstance(debug, bool):
         _debug = debug
     else:
@@ -80,6 +97,8 @@ def start(token=None,
                                                                                          True) in _TRUE_VALUES
     async_start = os.environ.get('ROOKOUT_ASYNC_START', False) in _TRUE_VALUES
 
+    _fork = fork or os.environ.get('ROOKOUT_ENABLE_FORK', False) in _TRUE_VALUES
+
     try:
         from rook.exceptions.tool_exceptions import RookMissingToken, RookInvalidToken, RookVersionNotSupported, \
             RookCommunicationException, RookInvalidOptions, RookLoadError, RookOldServers
@@ -134,17 +153,24 @@ def start(token=None,
                 if token is not None:
                     _validate_token(token)
 
+            if _debug:
+                _print_user_configuration(token=token[:5] + "....." if token else None, host=host, port=port,
+                                          proxy=proxy, throw_errors=throw_errors, log_level=log_level,
+                                          log_to_stderr=log_to_stderr, log_file=log_file, git_commit=git_commit,
+                                          git_origin=git_origin, tags=tags, labels=labels, async_start=async_start,
+                                          use_import_hook=use_import_hook, fork=_fork)
+
             if (host == "staging.cloud.agent.rookout.com") or (host == "cloud.agent.rookout.com"):
                 raise RookOldServers()
 
             from rook.logger import logger
             from rook.config import VersionConfiguration
-            logger.debug("Rookout SDK for Python, " + VersionConfiguration.VERSION)
+            logger.debug("Rookout SDK for Python, Version:" + VersionConfiguration.VERSION + " Commit:" + VersionConfiguration.COMMIT)
 
             import rook.singleton
             _rook = rook.singleton.singleton_obj
 
-            return _rook.connect(token, host, port, proxy, tags, labels, async_start=async_start)
+            return _rook.connect(token, host, port, proxy, tags, labels, async_start, _fork)
         except (RookMissingToken, RookInvalidToken, RookVersionNotSupported, RookOldServers) as e:
             if not _throw_errors:
                 six.print_("[Rookout] Failed to start Rookout:", e, file=sys.stderr)
@@ -186,6 +212,15 @@ def stop():
     _rook = None
 
 
+def restart(labels=None,
+            tags=None):
+    global _rook
+    if _rook is None:
+        return
+
+    _rook.restart(tags, labels)
+
+
 def _normalize_string(obj):
     if six.PY2:
         if isinstance(obj, str):
@@ -214,3 +249,14 @@ def _validate_label(label):
 
     if label.startswith("$"):
         raise RookInvalidLabel(label)
+
+
+def _print_user_configuration(**kwargs):
+    try:
+        config_string = ""
+        for key, value in kwargs.items():
+            if value:
+                config_string = config_string + ("%s: %s, " % (key, value))
+        six.print_("RookOptions: " + config_string)
+    except:
+        pass
