@@ -27,12 +27,23 @@ from ..logger import logger
 from rook.protobuf import variant_pb2
 
 from rook.config import ProtobufConfiguration
+from google.protobuf.descriptor import Descriptor as google_descriptor
 
 try:
     import numpy
 except ImportError:
     numpy = None
 
+try:
+    import torch
+except ImportError:
+    torch = None
+
+try:
+    import multidict
+except ImportError:
+    multidict = None
+
 if six.PY2:
     from types import TypeType
 
@@ -158,6 +169,12 @@ class NamespaceSerializer(object):
                 self._dump_traceback(obj, variant, current_depth, config, log_errors)
             elif NamespaceSerializer.is_numpy_obj(obj):
                 self._dump_primitive(obj.item(), str(type(obj)), variant, config.max_string)
+            elif NamespaceSerializer.is_torch_obj(obj):
+                self._dump_primitive(str(obj), str(type(obj)), variant, config.max_string)
+            elif NamespaceSerializer.is_multidict_obj(obj):
+                self._dump_primitive(str(obj), str(type(obj)), variant, config.max_string)
+            elif NamespaceSerializer.is_protobuf_obj(obj):
+                self._dump_protobuf(obj, variant, current_depth, config, log_errors)
             elif hasattr(obj, '__dict__'):
                 self._dump_user_class(obj, variant, current_depth, config)
             else:
@@ -356,6 +373,19 @@ class NamespaceSerializer(object):
                 self._dump_python_object(key, pair.first, current_depth+1, config, log_errors)
                 self._dump_python_object(value, pair.second, current_depth+1, config, log_errors)
 
+    def _dump_protobuf(self, obj, variant, current_depth, config, log_errors):
+        variant.variant_type = variant.VARIANT_OBJECT
+        if hasattr(obj, 'DESCRIPTOR'):
+            for field in obj.ListFields():
+                try:
+                    attribute = variant.attributes.add()
+                    attribute.name = field[0].name
+
+                    self._dump_python_object(field[1], attribute.value, current_depth - 1, config,
+                                                 log_errors)
+                except:
+                    pass
+
     def _dump_exception(self, exc, variant, current_depth, config, log_errors):
         variant.variant_type = variant.VARIANT_OBJECT
 
@@ -367,7 +397,6 @@ class NamespaceSerializer(object):
         variant.variant_type = variant.VARIANT_OBJECT
 
     def _dump_not_supported(self, obj, variant):
-        logger.warning("Unsupported type in serializer: %s".format(type(obj)))
         variant.variant_type = variant.VARIANT_UKNOWN_OBJECT
 
     def _dump_dumped_object_namespace(self, namespace, variant, log_errors):
@@ -577,3 +606,28 @@ class NamespaceSerializer(object):
             return False
 
         return isinstance(obj, numpy.generic)
+
+    @staticmethod
+    def is_torch_obj(obj):
+        if not torch:
+            return False
+
+        module = getattr(type(obj), '__module__', None)
+        if not module:
+            return False
+
+        return module.startswith('torch')
+
+    @staticmethod
+    def is_multidict_obj(obj):
+        if not multidict:
+            return False
+
+        return isinstance(obj, (multidict._multidict.MultiDict, multidict._multidict.CIMultiDict, multidict._multidict.MultiDictProxy, multidict._multidict.CIMultiDictProxy))
+
+    @staticmethod
+    def is_protobuf_obj(obj):
+        if hasattr(obj, "DESCRIPTOR"):
+            return isinstance(obj.DESCRIPTOR, google_descriptor)
+
+        return False
