@@ -32,18 +32,4 @@ class ContainerNamespace(dict, Namespace):
         else:
             return dict.__getattribute__(self, item)
 
-    def to_dict(self):
-        namespaces = {}
-        for key, value in six.iteritems(self):
-            namespaces[key] = value.to_dict()
-
-        return namespaces
-
-    def to_simple_dict(self):
-        namespaces = {}
-        for key, value in six.iteritems(self):
-            namespaces[key] = value.to_simple_dict()
-
-        return namespaces
-
     METHODS = (size,)
