@@ -27,14 +27,6 @@ class DelayedNamespace(namespace.Namespace):
         self._load()
         return self.namespace.read_key(key)
 
-    def to_dict(self):
-        self._load()
-        return self.namespace.to_dict()
-
-    def to_simple_dict(self):
-        self._load()
-        return self.namespace.to_simple_dict()
-
     def get_variant(self):
         self._load()
         return self.variant
