@@ -20,7 +20,7 @@ class PythonObjectNamespace(Namespace):
         STRICT_MAX_COLLECTION_DEPTH = 1
         STRICT_MAX_STRING = 128
 
-        DEFAULT_MAX_DEPTH = 3
+        DEFAULT_MAX_DEPTH = 4
         DEFAULT_MAX_WIDTH = 20
         DEFAULT_MAX_COLLECTION_DEPTH = 2
         DEFAULT_MAX_STRING = 512
@@ -119,6 +119,12 @@ class PythonObjectNamespace(Namespace):
         try:
             return PythonObjectNamespace(self.obj[key])
         except (KeyError, IndexError, TypeError):
+            # If key is a string and object is a dictionary check if any key within the dictionary stringifies to key
+            if isinstance(key, six.string_types) and isinstance(self.obj, dict):
+                for iteratorKey in self.obj:
+                    if str(iteratorKey) == key:  # The str() is the important part
+                        return PythonObjectNamespace(self.obj[iteratorKey])
+
             raise RookKeyNotFound(key)
 
     def type(self, args=None):
