@@ -305,7 +305,7 @@ class ImportService(object):
                             notification.aug.send_warning(Error(exc=RookSourceFilePathSuggestion(notification.module_filename, module_filename)))
 
     def _get_module_path(self, module):
-        if module is None:
+        if module is None or not hasattr(module, '__name__') or not hasattr(module, '__file__'):
             return None
         result = self._path_cache.get(module.__name__)
 
