@@ -58,13 +58,16 @@ class _Singleton(object):
         if self._services_started:
             return
 
-        self._id = uuid.uuid4().hex
+        self._init_id()
         self._output = Output(self._id)
 
         self._trigger_services.start()
         self._aug_manager = AugsManager(self._trigger_services, self._output)
         self._services_started = True
 
+    def _init_id(self):
+        self._id = uuid.uuid4().hex
+
     def _stop_trigger_services(self):
         if not self._services_started:
             return
@@ -77,13 +80,13 @@ class _Singleton(object):
     def get_trigger_services(self):
         return self._trigger_services
 
-    def connect(self, token, host, port, proxy, tags=None, labels=None, async_start=False):
+    def connect(self, token, host, port, proxy, tags=None, labels=None, async_start=False, fork=False):
         """Connect to the Agent."""
         if self._agent_com:
             raise RookInterfaceException("Multiple connection attempts not supported!")
 
         if install_fork_handler:
-            install_fork_handler()
+            install_fork_handler(fork)
 
         logger.debug("Initiating AgentCom-\t%s:%d", host, int(port))
 
@@ -110,6 +113,21 @@ class _Singleton(object):
 
         self._stop_trigger_services()
 
+    def restart(self, tags=None, labels=None):
+        logger.info("Restarting agent: " + self._id)
+        if not self._agent_com:
+            raise RookInterfaceException("Could not restart connection since it was not started")
+
+        self.flush()
+
+        self._init_id()
+        logger.info("New agent id is %s", self._id)
+
+        self._output.set_agent_id(self._id)
+        self._agent_com.update_info(self._id, tags, labels)
+
+        self._agent_com.restart()
+
     def pre_fork(self):
         # AgentCom is fork safe (the child will lose the thread) so there's nothing we need to do with it
         self._trigger_services.pre_fork()
